@@ -198,9 +198,9 @@ int XLALSimIMRPhenomAGenerateTD(
       XLAL_ERROR(XLAL_EFUNC);
   }
 
-  /* generate hcross, which is hplus w/ GW phase shifted by pi/2
-   * <==> orb. phase shifted by pi/4 */
-  IMRPhenomAGenerateTD(hcross, LAL_PI_4, deltaT, m1, m2, f_min, f_max_prime, distance, params);
+  /* generate hcross, which is hplus w/ GW phase shifted by -pi/2
+   * <==> orb. phase shifted by -pi/4 */
+  IMRPhenomAGenerateTD(hcross, -LAL_PI_4, deltaT, m1, m2, f_min, f_max_prime, distance, params);
   XLALFree(params);
   if (!(*hcross)) {
       XLALDestroyREAL8TimeSeries(*hplus);
@@ -241,6 +241,28 @@ double XLALSimIMRPhenomBComputeChi(
     return (m1 * s1z + m2 * s2z) / (m1 + m2);
 }
 
+/**
+ * Compute the default final frequency 
+ */
+double XLALSimIMRPhenomAGetFinalFreq(
+    const REAL8 m1,
+    const REAL8 m2
+) {
+    BBHPhenomParams *phenomParams;
+    phenomParams = ComputeIMRPhenomAParams(m1, m2);
+    return phenomParams->fCut;
+}
+
+double XLALSimIMRPhenomBGetFinalFreq(
+    const REAL8 m1,
+    const REAL8 m2,
+    const REAL8 chi
+) {
+    BBHPhenomParams *phenomParams;
+    phenomParams = ComputeIMRPhenomBParams(m1, m2, chi);
+    return phenomParams->fCut;
+}
+
 /**
  * Driver routine to compute the spin-aligned, inspiral-merger-ringdown
  * phenomenological waveform IMRPhenomB in the time domain.
@@ -306,9 +328,9 @@ int XLALSimIMRPhenomBGenerateTD(
       XLAL_ERROR(XLAL_EFUNC);
   }
 
-  /* generate hcross, which is hplus w/ GW phase shifted by pi/2
-   * <==> orb. phase shifted by pi/4 */
-  IMRPhenomBGenerateTD(hcross, LAL_PI_4, deltaT, m1, m2, chi, f_min, f_max_prime, distance, params);
+  /* generate hcross, which is hplus w/ GW phase shifted by -pi/2
+   * <==> orb. phase shifted by -pi/4 */
+  IMRPhenomBGenerateTD(hcross, -LAL_PI_4, deltaT, m1, m2, chi, f_min, f_max_prime, distance, params);
   XLALFree(params);
   if (!(*hcross)) {
       XLALDestroyREAL8TimeSeries(*hplus);
@@ -896,13 +918,13 @@ static size_t find_instant_freq(const REAL8TimeSeries *hp, const REAL8TimeSeries
   size_t k = start + 1;
   const size_t n = hp->data->length - 1;
 
-  /* complex_h := hp - i hc := A e^{i \phi}. Hence \phi = arctan(-hc/hp) 
-  and F = d \phi/dt = (-hp hc' + hc hp') / (2 \pi A^2)
+  /* complex_h := hp + i hc := A e^{-i \phi}. Hence \phi = arctan(-hc/hp)
+  and F = d \phi/dt = (hp hc' - hc hp') / (2 \pi A^2)
   We use first order finite difference to compute the derivatives hp' and hc'*/
   for (; k < n; k++) {
     const REAL8 hpDot = (hp->data->data[k+1] - hp->data->data[k-1]) / (2 * hp->deltaT);
     const REAL8 hcDot = (hc->data->data[k+1] - hc->data->data[k-1]) / (2 * hc->deltaT);
-    REAL8 f = -hcDot * hp->data->data[k] + hpDot * hc->data->data[k];
+    REAL8 f = hcDot * hp->data->data[k] - hpDot * hc->data->data[k];
     f /= LAL_TWOPI;
     f /= hp->data->data[k] * hp->data->data[k] + hc->data->data[k] * hc->data->data[k];
     if (f >= target) return k - 1;
